<?php
/*
Plugin Name: Food Lister
Plugin URI: http://www.startnet.co.uk/
Description: Create restaurant menus from a simple CSV file! Display a menu of food from a CSV file, which includes a cost calculator! can also go to a checkout page and emails the order using a Contact 7 form.
Uses shortcodes:
to display a food menu: [food_lister menufile="CSV FILENAME UPLOADED TO MEDIA"] <no_billing=1>] 
to display a simple Canape calculator: [canape_calc]
to display the order summary on the order checkout page: [output_ordered_items]
Version: 1.0
Author: James Reed
Author URI: http://www.startnet.co.uk
License: GPL
*/
/*
CSV FILE FORMAT:
name,css tag,price,extra,multiple
extra = extra text after the price eg. per person
multiple = units per item, default is 1 eg. 10 = will increment counter by 10
*/
?>
<?php
// check constant it not defined elsewhere
defined('FOOD_LISTER_DEFAULT_MENUFILE') or DEFINE("FOOD_LISTER_DEFAULT_MENUFILE", "");

/* Runs when plugin is activated */
register_activation_hook(__FILE__,'food_lister_install'); 

/* Runs on plugin deactivation*/
register_deactivation_hook( __FILE__, 'food_lister_remove' );

add_action( 'admin_enqueue_scripts', 'food_lister_scripts');
function food_lister_scripts()
{
    // Register the script like this for a plugin:
    wp_register_script( 'custom-script', plugins_url( '/js/food_lister_admin.js', __FILE__ ),array( 'jquery' ) );
	wp_register_style( 'custom-style', plugins_url( '/css/food_lister_admin.css', __FILE__  ) );	
	wp_register_style( 'custom-jqui', plugins_url( '/css/jquery-ui.css', __FILE__  ) );	

	wp_enqueue_script('jquery-ui-datepicker');
	
    wp_enqueue_script( 'custom-script' );
	wp_enqueue_style( 'custom-style' );
	wp_enqueue_style( 'custom-jqui' );
}


function food_lister_install() {

}

function food_lister_remove() {
/* Deletes the database field */
	unregister_setting( 'food_lister_group', 'food_lister_contact_form'); 
	unregister_setting( 'food_lister_group', 'food_lister_page'); 
}
	
function food_lister_settings() {
	register_setting( 'food_lister_group', 'food_lister_contact_form'); 
	register_setting( 'food_lister_group', 'food_lister_page'); 

} 

add_action( 'admin_init', 'food_lister_settings' );

// register food lister menu
if ( is_admin() ){
	/* Call the html code */
	add_action( 'admin_menu', 'register_food_lister_menu_page' );
}
function register_food_lister_menu_page(){
    add_menu_page( 'Food Lister - Add CSV Menus', 'Food Lister', 'manage_options', 'food_lister', 'food_lister_html_page', plugins_url( 'food_lister/images/food_lister_icon.png' ), 6 ); 
//	 add_submenu_page( 'tennis_register', 'Tennis Register Half Term Dates', 'Half Term Dates', 'manage_options', 'half_term_settings', 'half_term_page');
}


function food_lister_html_page() {
global $food_lister_notice;
?>
<div id="food_lister_admin">
<h2>Easy Food Lister Menu System Plugin - by Startnet Ltd</h2>
<p><strong>Important note: </strong>You must have Contact Form 7 and Contact Form 7 Modules - Hidden Fields plugins installed, otherwise the menu system won't be able to checkout and send an email.</p>
</p>
<?php 
if ( is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) ) {
	echo "<p>Contact Form 7 is installed and active &#10003;</p>";
} 
else { echo "<p><strong>PLEASE INSTALL THE PLUGIN: Contact Form 7</strong> otherwise you won't be able to email any menu choices.</p>"; }
if ( is_plugin_active( 'contact-form-7-modules/hidden.php' ) ) {
	echo "<p>Contact Form 7 Modules - Hidden Fields is installed and active &#10003;</p>";
} 
else { echo "<p><strong>PLEASE INSTALL THE PLUGIN: Contact Form 7 Modules - Hidden Fields</strong> otherwise you won't be able to email any menu choices.</p>"; }

// check for notices
if ($food_lister_notice!="") {
	echo '<p class="food_lister_notice">'.$food_lister_notice.'</p>';
}
?>
<hr>
<p><strong>If this is the first time you've used this plugin, do the following :</strong></br>
1) Click the 'Add Food Lister Form to Contact Form 7' button. </br>
2) Click the 'Add Food Lister Checkout Page' button. </br>
3) Choose "Food Order Form" and "Send Your Order Details" in the select boxes below.</br>
4) Click Save Changes.</br>
5) <a href="<?php echo plugins_url( '', __FILE__ )."/example_menu.csv"?>">Download</a>, edit and then upload the example Menu CSV file</br>
6) Add the shortcode <em>[food_lister menufile="example_menu.csv"]</em> to a page of your choice.</br>
7) View that page and your menu will be displayed!
</p>
<p>
<strong>Notes on the menu CSV file.</strong></br>
CSV file should have the following headers:</br>
name = the food item name or text to display</br>
css = CSS tag to use eg.h2 for a header, p for a paragraph.</br>
price = the price of the item, leave blank for no price</br>
extra = any text to add after the price eg. per person</br>
multiple = use if you have to order the food item in multiples eg. if some canapés should be ordered in multiples of 10.</br>
<a href="<?php echo plugins_url( '', __FILE__ )."/example_menu.csv"?>">Click here</a> to download an example CSV menu.
</p>
<p><button id="upload_to_media_button">Click to Upload CSV Files</button>&nbsp;<a id="refresh_food_lister_page">Click to refresh CSV menu list below after uploading CSV</a></p>
<form method="POST" id="add_cf7_form">
<input type="submit" class="fl_submit" value="Add Food Lister Form to Contact Form 7" name="add_cf7_form" id="add_cf7_form">
<?php wp_nonce_field( 'add_cf7_form','food_lister_check_nonce' ); ?>
</form>
<form method="POST" id="add_cf7_form">
<input type="submit" class="fl_submit" value="Add Food Lister Checkout Page" name="add_food_lister_page" id="add_food_lister_page">
<?php wp_nonce_field( 'add_food_lister_page','food_lister_check_nonce' ); ?>
</form>
<hr>
<p><strong>Shortcodes that can be used in pages/posts :</strong></p>
<p>[food_lister menufile="FILENAME.CSV" no_billing=1] - this displays your menu on the page with a price calculator. If 'no_billing=1' is set then the price calculator and checkout button will not display.</p>
<p>[canape_calc] - this displays a very simple canapé calculator. </p>
<p>[output_ordered_items] - this should only be used on the checkout order page.</p>
<hr>
<form action="options.php" method="post">
<?php settings_fields( 'food_lister_group' ); 
do_settings_sections( 'food_lister_group' );
?>
    <div>
    <label for="food_lister_contact_form">Contact 7 Form to use: </label>
    <select name="food_lister_contact_form" id="foot_lister_contact_form">
	<?php
	$co=get_option('food_lister_contact_form');
	$args=array('post_type' => 'wpcf7_contact_form','posts_per_page'=>-1); 
	$cf7_posts = new WP_Query($args);
	if($cf7_posts->have_posts()) : 
      while($cf7_posts->have_posts()) : 
         $cf7_posts->the_post();
         $t=get_the_title();
		 $i=get_the_id();
		 if ($co==$i) { $s="selected"; } else { $s=""; }
		 echo "<option value='$i' $s>$t (id=$i)</option>";      
    endwhile;
   else:
    echo '<p>No forms found!</p>';
   endif;
   ?>
    </select>
	</div>
    <div>
 
	<label for="food_lister_page">Page to use for order checkout : </label>
    <select name="food_lister_page" id="foot_lister_page">
	<?php
	$co=get_option('food_lister_page');
	$args=array('post_type' => 'page','posts_per_page'=>-1); 
	$cf7_posts = new WP_Query($args);
	if($cf7_posts->have_posts()) : 
      while($cf7_posts->have_posts()) : 
         $cf7_posts->the_post();
         $t=get_the_title();
		 $i=get_the_id();
		 if ($co==$i) { $s="selected"; } else { $s=""; }
		 echo "<option value='$i' $s>$t (id=$i)</option>";      
    endwhile;
   else:
    echo '<p>No pages found!</p>';
   endif;
   ?>
    </select>
	</div>
<input type="hidden" name="action" value="update" />
<input type="submit" value="<?php _e('Save Changes') ?>" />
</form>
<hr>
    <div>
	<p>To view the shortcode for your menu you can use the button below.</p>
    <label for="create_food_page">Choose CSV Menu : </label>
    <select name="create_food_page_id" id="create_food_shortcode_id">
	<?php
	$query_images_args = array(
    'post_type'      => 'attachment',
    'post_status'    => 'inherit',
    'posts_per_page' => - 1,
	'post_parent' => null, // any parent 
);
	$query_images = new WP_Query( $query_images_args );
$images = array();
foreach ( $query_images->posts as $image ) {
    $fname=wp_get_attachment_url( $image->ID );
	$sname=$image->post_title;
	if (substr($fname,-3)=="csv") { echo "<option value=\"$sname\">$sname</option><br>"; }
	}
?>
</select>
Display prices: <input type="checkbox" id="create_food_page_check" checked></br>
<input type="button" class="fl_submit" value="Display Shortcode" name="create_food_page" id="create_food_page_button">
<p>Shortcode to use in your pages/posts : <span id="create_food_page_shortcode"></div></p>
<hr>
<?php

	?>
</div><!-- food_lister_admin -->

	<?php 
} // food_lister_html_page


function food_lister_add_contact_form_7_food_form() {
global $food_lister_notice;

$current_user = wp_get_current_user();
$user_email = $current_user->user_email;
$admin_email = get_option( 'admin_email' );
$blog_name = get_option( 'blogname' );
$blog_home = get_option( 'home' );
	
$post_content="SEE CONTACT FORM 7";

// Create post object
$my_post = array(
  'post_title'    => 'Food Order Form',
  'post_content'  => $post_content,
  'post_status'   => 'publish',
  'post_type' => 'wpcf7_contact_form',
  'post_author'   => 1,
  'comment_status' => 'closed',
  'ping_status' => 'closed',
);

// Insert the Contact Form 7 post into the database
$post_id=wp_insert_post( $my_post );

// add post meta
add_post_meta($post_id,'_form',	"<p>Your Name (required)<br />\n    [text* your-name] </p>\n\n<p>Your Email (required)<br />\n    [email* your-email] </p>\n\n<p>\nApprox how many people will attend your event? [text* party_size 4/4]&nbsp;\nHow long will it be? [select hours id:hours \"1-2\" \"2-4\" \"4+\"] hours\nDate of your event DD/MM/YY [text when id:when 10/]</p>\n\n<p>Extra details or questions<br />\n    [textarea your-message] </p>\n\n<p>[submit \"Send my order\"]</p>\n\n[hidden order_items id:order_items]\n[hidden order_prices id:order_prices]\n[hidden order_qtys id:order_qtys]\n[hidden order_totals id:order_totals]\n[hidden grand_total id:grand_total]\n[hidden order_info id:order_info]\n[hidden menu_name id:menu_name]\n[hidden menu_notes id:menu_notes]");

$a=array('subject'=>"Order from $blog_name",
'sender'=>"$blog_name Website <$admin_email>",
'body'=>"From: [your-name] <a href='mailto:[your-email]'>[your-email]</a>\n\nApprox number of people attending event: [party_size]\nHow long event will run: [hours] hours\nDate of event: [when]\n\nExtra details or questions :\n[your-message]\n\n<table>\n<tr><td colspan=\"4\"><b>Order details:</b></td></tr>\n<tr><td colspan=\"4\">This order was taken from the [menu_name] menu.</td></tr>\n<tr><td colspan=\"4\">[menu_notes]</td></tr>\n<tr><td><b>Items:</b></td><td><b>Price:</b></td><td><b>Qty:</b></td><td><b>Total:</b></td></tr>\n<tr><td>[order_items]</td><td>[order_prices]</td><td>[order_qtys]</td><td>[order_totals]</td></tr>\n<tr><td><b>Grand total:</b></td><td>&nbsp;</td><td>&nbsp;</td><td>[grand_total]</td></tr>\n<tr><td colspan=\"4\">[order_info]</td></tr>\n</table>\n\n--\nThis e-mail was sent from a contact form on the $blog_name $blog_home",
'recipient'=>"$user_email",
'use_html'=>1);
add_post_meta($post_id,'_mail',	$a);

$a=array('subject'=>"[your-subject]",
'sender'=>[your-name] <[your-email],
'body'=>"Message Body:\n[your-message]\n\n--\nThis e-mail was sent from a contact form on $blog_name $blog_home",
'recipient'=>"[your-email]"
);
add_post_meta($post_id,'_mail_2',$a);

$a='a:21:{s:12:"mail_sent_ok";s:43:"Your message was sent successfully. Thanks.";s:12:"mail_sent_ng";s:93:"Failed to send your message. Please try later or contact the administrator by another method.";s:16:"validation_error";s:74:"Validation errors occurred. Please confirm the fields and submit it again.";s:4:"spam";s:93:"Failed to send your message. Please try later or contact the administrator by another method.";s:12:"accept_terms";s:35:"Please accept the terms to proceed.";s:16:"invalid_required";s:31:"Please fill the required field.";s:17:"captcha_not_match";s:31:"Your entered code is incorrect.";s:14:"invalid_number";s:28:"Number format seems invalid.";s:16:"number_too_small";s:25:"This number is too small.";s:16:"number_too_large";s:25:"This number is too large.";s:13:"invalid_email";s:28:"Email address seems invalid.";s:11:"invalid_url";s:18:"URL seems invalid.";s:11:"invalid_tel";s:31:"Telephone number seems invalid.";s:23:"quiz_answer_not_correct";s:27:"Your answer is not correct.";s:12:"invalid_date";s:26:"Date format seems invalid.";s:14:"date_too_early";s:23:"This date is too early.";s:13:"date_too_late";s:22:"This date is too late.";s:13:"upload_failed";s:22:"Failed to upload file.";s:24:"upload_file_type_invalid";s:30:"This file type is not allowed.";s:21:"upload_file_too_large";s:23:"This file is too large.";s:23:"upload_failed_php_error";s:38:"Failed to upload file. Error occurred.";}';
$b=unserialize($a);
add_post_meta($post_id,'_messages',	$b);

add_post_meta($post_id,'_additional_settings',	'');

// set food_lister_contact form to $post_id
update_option('food_lister_contact_form',$post_id);

$food_lister_notice="Added form to Contact Form 7</br>";

} // end of food_lister_add_contact_form_7_food_form

function add_food_lister_page() {
global $food_lister_notice;

$food_lister_contact_form=get_option('food_lister_contact_form');

// Create post object
$post_content=<<<EOT
Please fill in the form and click "Send my order".

[contact-form-7 id="380" title="Food Order Form"]

[output_ordered_items]

&nbsp;
EOT;

$my_post = array(
  'post_title'    => 'Send Food Order Details Page',
  'post_content'  => $post_content,
  'post_status'   => 'publish',
  'post_type' => 'page',
  'post_author'   => 1,
  'comment_status' => 'closed',
  'ping_status' => 'closed',
);

// Add the Food Order Details page to Wordpress
$post_id=wp_insert_post( $my_post );

// update food_lister_page to this $post_id
update_option('food_lister_page',$post_id);

$food_lister_notice="Added new page for food lister.</br>";

}

/* ADD SHORTCODE TO A PAGE
function create_food_page($food) {

// Create post object
$post_content=<<<EOT
Please fill in the form and click "Send my order".

&nbsp;

[contact-form-7 id="27" title="Food Order Form"]

&nbsp;

&nbsp;
EOT;

$my_post = array(
  'post_title'    => '$food Menu',
  'post_content'  => $post_content,
  'post_status'   => 'publish',
  'post_type' => 'page',
  'post_author'   => 1,
  'comment_status' => 'closed',
  'ping_status' => 'closed',
);

// Insert the page
$post_id=wp_insert_post( $my_post );

}
*/

//tell wordpress to register the foot_lister and canape_calc shortcodes
add_shortcode("food_lister", "food_lister_handler");
add_shortcode("canape_calc", "food_lister_canape_calc_handler");
add_shortcode("output_ordered_items", "food_lister_output_order_items");

add_action( 'wp_enqueue_scripts', 'food_lister_scripts_basic' );

// ALLOW CSV UPLOADING TO MEDIA FOLDER
add_filter('upload_mimes', 'food_lister_my_upload_mimes');

function food_lister_my_upload_mimes ( $existing_mimes=array() ) {
    $existing_mimes['csv'] = 'text/csv';
    return $existing_mimes;
}

function food_lister_scripts_basic()
{
    // Register the script like this for a plugin:
    wp_register_script( 'custom-script', plugins_url( '/js/food_lister.js', __FILE__ ),array( 'jquery' ) );
	wp_register_style( 'custom-style', plugins_url( '/css/food_lister.css', __FILE__  ) );
	
    wp_enqueue_script( 'custom-script' );
	wp_enqueue_style( 'custom-style' );

}

function food_lister_handler($incomingfrompost) {

$incomingfrompost=shortcode_atts(array(
    "menufile" => FOOD_LISTER_DEFAULT_MENUFILE,
	"no_billing" => ""
	),$incomingfrompost
	);

  //run function that actually does the work of the plugin
  $demofl_output = food_lister_function($incomingfrompost);
  //send back text to replace shortcode in post
  
  return $demofl_output;
}

// display HTML menu from CSV file
/* CSV fields:
name = Item name or menu text to display
css = CSS tag to use eg.H2 for a header
price = price of the item, leave blank for no price
extra = text to add after the price eg. per person
multiple = if you have to order in multiples eg. some items should be ordered in multiples of 10
*/
function food_lister_function($incomingfromhandler) {
$demofl_output="";
$menufile = wp_specialchars_decode($incomingfromhandler["menufile"]);
$no_billing = wp_specialchars_decode($incomingfromhandler["no_billing"]);

$food_lister_page=get_option('food_lister_page');
$food_lister_contact_form=get_option('food_lister_contact_form');

// discover where the file actually is in the upload folder  
$upload_dir=wp_upload_dir();

$Directory = new RecursiveDirectoryIterator($upload_dir['basedir']);
$Iterator = new RecursiveIteratorIterator($Directory);
$Regex = new RegexIterator($Iterator, "/$menufile/", RecursiveRegexIterator::GET_MATCH);

$objects=iterator_to_array($Regex);
$files=array();
foreach($objects as $filename=>$small_name) {
$files[]=$filename;
}

$items_name=array();
$items_css=array();
$items_price=array();
$items_extra=array();
$items_multiple=array();

// go through the menu file
if (($handle = fopen($files[0], "r")) !== FALSE) {
    while (($data = fgetcsv($handle, 4000, ",")) !== FALSE) {
	$row++;
	if ($row==1) continue;	
$data[0]=htmlentities(trim($data[0])); // item_name
$data[1]=trim($data[1]); // css
$data[2]=trim($data[2]); // item_price
$data[3]=trim($data[3]); // extra
$data[4]=trim($data[4]); // multiple items?
	
//	if ($data[3]=="") { $data[3]=10; }
	
array_push($items_name,$data[0]);
if ($data[1]=="") { $data[1]="p"; }
array_push($items_css,$data[1]);
array_push($items_price,$data[2]);
array_push($items_extra,$data[3]);
array_push($items_multiple,$data[4]);
}
}
fclose($handle);
//$demofl_output.="Items read : ".sizeof($items_name)."<br>\n";

if ($no_billing==1) { $no_billing="no_billing"; } else { $no_billing=""; }

$demofl_output.="<div class=\"food_menu $no_billing\">";
$demofl_output.='<div class="items_block">';

$pc=0;
for($i=0; $i<sizeof($items_name); $i++) {
$item_name=$items_name[$i];
$item_css=$items_css[$i];
$item_price=$items_price[$i];
$item_extra=$items_extra[$i];
$item_multiple=$items_multiple[$i];
if ($item_multiple=="") { $item_multiple=1; }

// if price is not blank then format the price
if ($item_price!="") {
 if (is_numeric($item_price)) {
 $item_price=number_format((float)$item_price, 2, '.', '');
 $aitem_price=$item_price;
 $item_price="&pound;$item_price";
 }
}

$other_css="";
// heading css
if ($item_css=="h2") { $other_css="heading"; if ($item_name!="") { $demofl_output.='<div class="item_info heading">'; } }
else {
 if ($item_price!="") {
 $pc++;
   if (($pc % 2)==0) { $odd_even_c="even"; }
   else { $odd_even_c="odd"; }
 }
 else { $odd_even_c=""; }
 if ($item_name!="") { $demofl_output.="<div class=\"item_info $odd_even_c\">"; }
}
 $show_price="";
 if ($item_price=="upon quote") { $show_price="upon_quote"; }

 $demofl_output.="<div class=\"item_name $other_css\"><$item_css>$item_name</$item_css></div><div class=\"item_price $show_price\">$item_price</div><div class=\"item_extra\">$item_extra</div>";
 if ($item_price!="") {
  $aitem_name=htmlentities($item_name);
  $demofl_output.="<div class=\"food_buttons\"><input class=\"less\" type=\"button\" value=\"-\"><input type=\"hidden\" class=\"aname\" value=\"$aitem_name\"><input type=\"hidden\" class=\"aprice\" value=\"$aitem_price\"><input class=\"amount\" type=\"textbox\" value=\"0\" size=\"2\"><input class=\"more\" type=\"button\" value=\"+\"><input type=\"hidden\" name=\"unit\" value=\"$item_multiple\"></div>";
 }
 
 $demofl_output.="<div style=\"clear:both\"></div>";
if ($item_name!="") { $demofl_output.="</div><!-- item_info -->"; }
 $demofl_output.="<div style=\"clear:both\"></div>";

 }

 $demofl_output.="</div><!-- items_block -->";
$demofl_output.="<div id=\"total_area\">";
 $demofl_output.="<br><div class=\"item_name total_heading\"><h2>Total:</h2></div><div class=\"currency\">&pound;</div><div id=\"total_price\">0</div></div>";
 $demofl_output.="<div style=\"clear:both\"></div>";

 $demofl_output.="<br><input type=\"button\" value=\"Send Order\" id=\"send_order\">";
 $demofl_output.="</div>";
 
 $demofl_output.="</div>";
 $demofl_output.='<form method="POST" action="/?page_id='.$food_lister_page.'" id="order_form"><input type="hidden" name="order_details" id="order_details">';
 $demofl_output.='<input type="hidden" name="menu_name" id="menu_name" value="'.get_the_title().'">';
 
 $menu_notes="";
 
 $demofl_output.='<input type="hidden" name="menu_notes" id="menu_notes" value="'.$menu_notes.'">';
 $demofl_output.='</form>';
 //process plugin
  //send back text to calling function
  return $demofl_output;
}

function food_lister_canape_calc_handler($incomingfrompost) {

  //run function that actually does the work of the plugin
  $demofl_output = food_lister_canape_calc_function($incomingfrompost);
  //send back text to replace shortcode in post
  
  return $demofl_output;
}

function food_lister_canape_calc_function() {

$output='
<div class="canape_calculator">
<p><i>Canap&eacute; Calculator - estimate the number of Canap&eacute;s you need</i></p>
<label>Number of people:</label><input type="text" id="canape_people" size="4" value="">&nbsp;
<label>How long is your party:</label><select id="canape_hours" size="1"><option value="1">1-2</option><option value="2">2-4</option><option value="3">4+</option></select> hours&nbsp;
<input type="button" id="canape_calc" value="Calculate"></p>
<div id="canapes_num"><p>&nbsp;</p></div>
</div>
';
return $output;
} // food_lister_canape_calc_function


function food_lister_output_order_items($atts) {
	$_POST  = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
	$menu_name=$_POST['menu_name'];
	$menu_notes=$_POST['menu_notes'];
		
	$output=food_lister_obtain_order_items();
$js="
<script type='text/javascript'>
jQuery(document).ready(function($) {
 $('input#order_items').val('".$output['item_names']."');
 $('input#order_prices').val('".$output['item_prices']."');
 $('input#order_qtys').val('".$output['item_qtys']."');
 $('input#order_totals').val('".$output['item_totals']."');
 $('input#grand_total').val('".$output['grand_total']."');
 $('input#order_info').val('".$output['order_info']."');
 $('input#menu_name').val('".htmlentities($menu_name)."');
 $('input#menu_notes').val('".htmlentities($menu_notes)."');
});
</script>
";
echo $js;
//$output.=$js;
			return $output['html'];
} // end of function food_lister_output_order_items

function food_lister_obtain_order_items() {
$output='<div id="order_details" style="width:100%;clear:both;">';
$output.="<h2>Your order details:</h2>";
	  $_POST  = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
	  $values = json_decode(stripcslashes($_POST['order_details']));
	  
	  global $menu_notes;
	  
	  if ($_POST['upon_quote']=="yes") { 
	   $output.="<p class='upon_quote_txt'><i>Where the price is &pound;0.00 - this means the price will be given upon quote.</i></p>";
	   $menu_notes="<p class='upon_quote_txt'><i>Where the price is &pound;0.00 - this means the price will be given upon quote.</i></p>";
	   }
	  
	  $output.='
		<div class="item_name heading">Item name:</div>
		<div class="item_price heading">Price:</div>
		<div class="item_qty heading">Qty:</div>
		<div class="item_total heading">Total:</div>
		<div style="clear:both"></div>';

		$grand_total=0;
$grand_qtys=0;
$item_names=""; $item_prices=""; $items_qtys=""; $items_totals="";

	  foreach($values as $value) {
		
		$item_name=$value->item_name;
		$item_price=$value->item_price;
		$item_qty=$value->item_qty;
		$grand_total+=$item_price * $item_qty;
		$grand_qtys+=$item_qty;
		
$item_total=$item_price * $item_qty;
$item_names.=$item_name.'\n';
$item_prices.='&pound;'.number_format((float)$item_price, 2, '.', '').'\n'; 
$items_qtys.=$item_qty.'\n'; 
$items_totals.='&pound;'.number_format((float)$item_total, 2, '.', '').'\n';

		
		$output.='
		<div class="item_name">'.$item_name.'</div>
		<div class="item_price">&pound;'.number_format((float)$item_price, 2, '.', '').'</div>
		<div class="item_qty">'.$item_qty.'</div>
		<div class="item_total">&pound;'.number_format((float)$item_total, 2, '.', '').'</div>
		<div style="clear:both"></div>';
		
	  }
	  
	  $output.='
	  <hr style="width:650px;float:left;">
		<div style="clear:both"></div>
		<div class="item_name heading">Grand total:</div>
		<div class="item_price">&nbsp;</div>
		<div class="item_qty">'.$grand_qtys.' items</div>
		<div class="item_total heading">&pound;'.number_format((float)$grand_total, 2, '.', '').'</div>
		<div style="clear:both"></div>';
	
	  $output.='</div><!-- order_details -->';
	  
	  $aoutput=array();
	  $aoutput['html']=$output;
	  $aoutput['item_names']=$item_names;
	  $aoutput['item_prices']=$item_prices;
	  $aoutput['item_qtys']=$items_qtys;
	  $aoutput['item_totals']=$items_totals;
	  $aoutput['grand_total']='&pound;'.number_format((float)$grand_total, 2, '.', '');

	  $aoutput['order_info']="Total of $grand_qtys pieces of ".count($values)." items."; 
	  $html_order_info="Total of ".count($values)." types of item."; 
	  $aoutput['html'].="<p>".$html_order_info."</p>";
	  
	  	  
	  
	  return $aoutput;
	  
} // food_lister_obtain_order_items





// when the buttons are clicked
function food_lister_check_buttons() {
global $food_lister_notice;
$food_lister_notice="";

if (current_user_can('manage_options')) :
	if (wp_verify_nonce( $_POST['food_lister_check_nonce'],'add_cf7_form' )) {
		if (isset($_POST['add_cf7_form'])) {
			food_lister_add_contact_form_7_food_form();
	}
	}

	if (wp_verify_nonce( $_POST['food_lister_check_nonce'],'add_food_lister_page' )) {
		if (isset($_POST['add_food_lister_page'])) {
			add_food_lister_page();
		}
	}

endif;
} // function food_lister_check_buttons
add_action('init', 'food_lister_check_buttons');

/*
function check_create_food_page() {
if (isset($_POST['create_food_page'])) {
	create_food_page($_POST['create_food_page_id']);
}
}
add_action('init', 'check_create_food_page');
*/

// for add to media button
add_action ( 'admin_enqueue_scripts', function () {
        if (is_admin ())
            wp_enqueue_media ();
} );


// Add settings link on plugin page
function food_lister_settings_link($links) { 
  $settings_link = '<a href="options-general.php?page=food_lister">Settings</a>'; 
  array_unshift($links, $settings_link); 
  return $links; 
}
$plugin = plugin_basename(__FILE__); 
add_filter("plugin_action_links_$plugin", 'food_lister_settings_link' );

?>
